<!-- [<img src="https://img.icons8.com/external-tal-revivo-filled-tal-revivo/96/external-markdown-a-lightweight-markup-language-with-plain-text-formatting-syntax-logo-filled-tal-revivo.png" align="right" width="25%" padding-right="350">]()

-->

# QAB

<!--
#### <code>❯ TBD </code>


<p align="left">
	<img src="https://img.shields.io/github/license/joman2/qab?style=flat-square&logo=opensourceinitiative&logoColor=white&color=b2b2f7" alt="license">
	<img src="https://img.shields.io/github/last-commit/joman2/qab?style=flat-square&logo=git&logoColor=white&color=b2b2f7" alt="last-commit">
	<img src="https://img.shields.io/github/languages/top/joman2/qab?style=flat-square&color=b2b2f7" alt="repo-top-language">
	<img src="https://img.shields.io/github/languages/count/joman2/qab?style=flat-square&color=b2b2f7" alt="repo-language-count">
</p>
<p align="left">
		<em>Built with the tools and technologies:</em>
</p>
<p align="left">
	<img src="https://img.shields.io/badge/Python-3776AB.svg?style=flat-square&logo=Python&logoColor=white" alt="Python">
</p>

-->

<br>

<details><summary>Table of Contents</summary>

- [Overview](#-overview)
- [Features](#-features)
- [Repository Structure](#-repository-structure)
- [Modules](#-modules)
- [Getting Started](#-getting-started)
    - [Prerequisites](#-prerequisites)
    - [Installation](#-installation)
    - [Usage](#-usage)
    - [Tests](#-tests)
- [Project Roadmap](#-project-roadmap)
- [Contributing](#-contributing)
- [License](#-license)
- [Acknowledgments](#-acknowledgments)

</details>
<hr>

## Overview

<code>❯ TBW </code>

---

## Features

<code>❯ TBW </code>

---

## Repository Structure

```sh
└── qab/
    ├── README.md
    ├── app_flows
    ├── testing_flows
    ├── __init__.py
    └── crawler.py
```
<!--
---

 ## Modules

<details closed><summary>.</summary>

| File | Summary |
| --- | --- |
| [crawler.py](https://github.com/joman2/qab/blob/main/crawler.py) | <code>❯ REPLACE-ME</code> |

</details>

-->

---

## Getting Started

### Prerequisites

**Python**: `version 3.10+`
**Conda**: `version 4+`

### Installation


1. Clone the qab repository:
```sh
❯ git clone https://github.com/joman2/qab
```


2. Create your conda environment:
```sh
❯ conda create -n qab python=3.10
```
<!--
3. Install the required dependencies:
```sh
❯ pip install -r requirements.txt
```
-->

### Usage

To run the project, execute the following commands:

```sh	
❯ conda activate qab
```

```sh
❯ python <your_testing_file>.py
```
<!--
### Tests

Execute the test suite using the following command:

```sh
❯ pytest
```

-->

## Available functions

#### Uninstall the desired package_name

```python
  def uninstall_app(package_name):
```

| Argument   | Type       | Description                           |
| :---------- | :--------- | :---------------------------------- |
| `package_name` | `string` | **Mandatory**. Package to uninstall |

```python
   def click_in_image(image_path, connection: u2.connect = None):
```

| Argument   | Type       | Description                           |
| :---------- | :--------- | :---------------------------------- |
| `image_path1` | `image_path2` | **Mandatory**. Package to uninstall |

---

## Project Roadmap
(no specific order)

- [X] **`Task 1`**: <strike>Make it usable</strike>
- [ ] **`Task 2`**: read and analyse logs;
- [ ] **`Task 3`**: record testing;
- [ ] **`Task 4`**: support multiple resolutions;
- [ ] **`Task 5`**: Package the project for PyPI;

---

<!--
## 🤝 Contributing

Contributions are welcome! Here are several ways you can contribute:

- **[Report Issues](https://github.com/joman2/qab/issues)**: Submit bugs found or log feature requests for the `qab` project.
- **[Submit Pull Requests](https://github.com/joman2/qab/blob/main/CONTRIBUTING.md)**: Review open PRs, and submit your own PRs.
- **[Join the Discussions](https://github.com/joman2/qab/discussions)**: Share your insights, provide feedback, or ask questions.

<details closed>
<summary>Contributing Guidelines</summary>

1. **Fork the Repository**: Start by forking the project repository to your github account.
2. **Clone Locally**: Clone the forked repository to your local machine using a git client.
   ```sh
   git clone https://github.com/joman2/qab
   ```
3. **Create a New Branch**: Always work on a new branch, giving it a descriptive name.
   ```sh
   git checkout -b new-feature-x
   ```
4. **Make Your Changes**: Develop and test your changes locally.
5. **Commit Your Changes**: Commit with a clear message describing your updates.
   ```sh
   git commit -m 'Implemented new feature x.'
   ```
6. **Push to github**: Push the changes to your forked repository.
   ```sh
   git push origin new-feature-x
   ```
7. **Submit a Pull Request**: Create a PR against the original project repository. Clearly describe the changes and their motivations.
8. **Review**: Once your PR is reviewed and approved, it will be merged into the main branch. Congratulations on your contribution!
</details>

<details closed>
<summary>Contributor Graph</summary>
<br>
<p align="left">
   <a href="https://github.com{/joman2/qab/}graphs/contributors">
      <img src="https://contrib.rocks/image?repo=joman2/qab">
   </a>
</p>
</details>

---

-->

## License

This project is protected under the [MIT](https://choosealicense.com/licenses/mit/) License. For more details, refer to the [LICENSE](https://github.com/joman2/qab/blob/main/README.md) file.

---

## Acknowledgments

- Resources used:

   - [uiautomator2](https://github.com/openatx/uiautomator2)
   - and others

---
